diff libpurple/protocols/msn/msg.h @ 31132:33b4ae796648

Rename "attribute" to "header" in a bunch of places. The SLP protocol is fashioned after HTTP. Well, more accurately after SIP. And these are generally referred to as headers pretty much everywhere.
author Mark Doliner <mark@kingant.net>
date Mon, 08 Feb 2010 07:41:15 +0000
parents 462cb893521b
children 35771ce2db52
line wrap: on
line diff
--- a/libpurple/protocols/msn/msg.h	Sat Feb 06 05:26:27 2010 +0000
+++ b/libpurple/protocols/msn/msg.h	Mon Feb 08 07:41:15 2010 +0000
@@ -109,8 +109,8 @@
 	MsnSlpHeader msnslp_header;
 	MsnSlpFooter msnslp_footer;
 
-	GHashTable *attr_table;
-	GList *attr_list;
+	GHashTable *header_table;
+	GList *header_list;
 
 	gboolean ack_ref;           /**< A flag that states if this message has
 								  been ref'ed for using it in a callback. */
@@ -295,24 +295,24 @@
 const char *msn_message_get_charset(const MsnMessage *msg);
 
 /**
  * Sets an attribute in a message.
  *
  * @param msg   The message.
  * @param attr  The attribute name.
  * @param value The attribute value.
  */
-void msn_message_set_attr(MsnMessage *msg, const char *attr,
+void msn_message_set_header(MsnMessage *msg, const char *name,
 						  const char *value);
 
 /**
- * Returns an attribute from a message.
+ * Returns the value of a header from a message.
  *
  * @param msg  The message.
  * @param attr The attribute.
  *
  * @return The value, or @c NULL if not found.
  */
-const char *msn_message_get_attr(const MsnMessage *msg, const char *attr);
+const char *msn_message_get_header_value(const MsnMessage *msg, const char *name);
 
 /**
  * Parses the body and returns it in the form of a hashtable.
@@ -295,24 +295,24 @@
 
 /**
- * Sets an attribute in a message.
+ * Sets a header in a message.
  *
@@ -295,24 +295,24 @@
  *
- * @param msg   The message.
- * @param attr  The attribute name.
- * @param value The attribute value.
+ * @param msg    The message.
+ * @param header The header name.
+ * @param value  The header value.
  */
@@ -295,24 +295,24 @@
  *
- * @param msg  The message.
- * @param attr The attribute.
+ * @param msg    The message.
+ * @param header The header value.
  *
  * @return The value, or @c NULL if not found.